==> cartography-0.98.0.tar.gz: cartography-0.98.0/MAINTAINERS.md <==
See https://github.com/lyft/cartography/#contributing for general contribution guidelines.

## Maintainers

List of community members who have shown they are committed to Cartography's continued development and are active in pull request reviews and community conversations.

- Alex Chantavy (https://github.com/achantavy): General catch-all
- Ramon Petgrave (https://github.com/ramonpetgrave64): General catch-all
- Jérémy Chapeau (https://github.com/resilience-jychp): Plugin development
- Ryan Lane (https://github.com/ryan-lane): Plugin development, general engineering best practices
- Marco Lancini (https://github.com/marco-lancini): Deployment and use-cases
- Kedar Ghule (https://github.com/kedarghule): Plugin development
- Purusottam Mupunu (https://https://github.com/mpurusottamc): Deployment and use-cases
- Chandan Chowdhury (https://github.com/chandanchowdhury): Plugin development


## Friends of Cartography

Not maintainers but are continually active in discussions and offer subject matter expertise or community advocacy (e.g. writing blog posts)

- Daniel D'Agostino (https://github.com/danielsaporo): Deployment and use-cases
- Ashley Lowde (https://github.com/alowde-ps): Deployment and use-cases


## Emeritus maintainers

Not actively involved in reviews, but Cartography would not exist without the contributions of these key community members.

- Sacha Faust (https://github.com/sachafaust)
- Andrew Johnson (https://github.com/SecPrez)
- Taya Steere (https://github.com/tmsteere)
- Evan Davis (https://github.com/ecdavis)

==> cartography-0.101.1.tar.gz: cartography-0.101.1/MAINTAINERS.md <==
See https://github.com/lyft/cartography/#contributing for general contribution guidelines.

## Maintainers

List of community members who have shown they are committed to Cartography's continued development and are active in pull request reviews and community conversations.

- Alex Chantavy (https://github.com/achantavy): General catch-all
- Ramon Petgrave (https://github.com/ramonpetgrave64): General catch-all
- Jérémy Chapeau (https://github.com/jychp): Plugin development
- Ryan Lane (https://github.com/ryan-lane): Plugin development, general engineering best practices
- Marco Lancini (https://github.com/marco-lancini): Deployment and use-cases
- Kedar Ghule (https://github.com/kedarghule): Plugin development
- Purusottam Mupunu (https://https://github.com/mpurusottamc): Deployment and use-cases
- Chandan Chowdhury (https://github.com/chandanchowdhury): Plugin development


## Friends of Cartography

Not maintainers but are continually active in discussions and offer subject matter expertise or community advocacy (e.g. writing blog posts)

- Daniel D'Agostino (https://github.com/danielsaporo): Deployment and use-cases
- Ashley Lowde (https://github.com/alowde-ps): Deployment and use-cases


## Emeritus maintainers

Not actively involved in reviews, but Cartography would not exist without the contributions of these key community members.

- Sacha Faust (https://github.com/sachafaust)
- Andrew Johnson (https://github.com/SecPrez)
- Taya Steere (https://github.com/tmsteere)
- Evan Davis (https://github.com/ecdavis)
